API docs for “spamfighter.plugin.IPartnerAuthorizerProvider”

# Class s.p.IPartnerAuthorizerProvider(INamedPlugin):

Part of spamfighter.plugin View Source View In Hierarchy

Интерфейс плагина, возвращающего ссылку на механизм авторизации партнеров.

Method | getPartnerAuthorizer | Получить механизм авторизации партнеров.

Inherited from INamedPlugin:

Method | name | Получить имя плагина.

def getPartnerAuthorizer(): (source)
Получить механизм авторизации партнеров.

Returns | домен по умолчанию. (type: `spamfighter.interfaces.IPartnerAuthorizer` )